@@ -1,12 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+import logging
+
 import requests
-
-from .config import MobioEnvironment, Mobio
-from src.common.system_config import SystemConfig
-
 from mobio.libs.Singleton import Singleton
 
+from .config import MobioEnvironment
+
+logger = logging.getLogger()
 
 @Singleton
 class MerchantConfig:
@@ -17,7 +18,6 @@ class MerchantConfig:
     MEDIA_HOST = 'media_host'
 
     def __init__(self):
-        self.sys_conf = SystemConfig()
         self.configs = {}
         self.current_merchant = ''
         self.admin_host = None
@@ -34,15 +34,13 @@ class MerchantConfig:
 
     def __request_get_merchant_auth(self, merchant_id):
         adm_url = MobioEnvironment.ADM_CONFIG.format(host=self.admin_host, merchant_id=merchant_id)
-        headers = {
-            "Authorization": Mobio.MOBIO_TOKEN
-        }
-        self.sys_conf.logger.debug('::get_merchant_auth: adm_url = %s' % adm_url)
-        response = requests.get(adm_url, headers=headers)
+
+        logger.debug('::get_merchant_auth: adm_url = %s' % adm_url)
+        response = requests.get(adm_url)
         response.raise_for_status()
 
         result = response.json()
-        self.sys_conf.logger.debug('::get_merchant_auth: result = %s' % result)
+        logger.debug('::get_merchant_auth: result = %s' % result)
 
         # media_host = result['data']['media_host']
         # if media_host.endswith('/'):
